function [ A ] = greedy_hcp( p, alpha, np, r, f)
%greedy_hcp: Two-pool greedy with specified hot/cold free space split
%   'p' is the fraction of free space devoted to the hot pool - see
%   SYSTOR '12 Eqs 20-22. 

    % return large value for p outside [0,1] so fminsearch will be
    % well-behaved
    if p < 0 || p > 1,
	A = 10000;
	return
    end

    alpha_h = (p*(alpha-1) + f) / f;                           % Eq. 21
    alpha_c = ((1-p)*(alpha-1) + (1 - f)) / (1 - f);           % Eq. 22
    A = r * greedy(alpha_h, np) + (1-r) * greedy(alpha_c, np); % Eq. 20
end

% Copyright 2012 Peter Desnoyers
% This file is free software: you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 2 of the License, or
% (at your option) any later version.
%
% It is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
% General Public License for more details. 
% You should have received a copy of the GNU General Public License
% along with this file. If not, see http://www.gnu.org/licenses/. 
