function [ A ] = lru_hc( alpha, r, f )
%lru_hc: Numeric solution of mixed LRU performance for hot/cold traffic
%   see SYSTOR '12 Eq. 14
    hot_term  = @(A_) r / (exp((r/f)*(alpha/A_))-1);
    cold_term = @(A_) (1-r) / (exp(((1-r)/(1-f))*(alpha/A_))-1);
    A = fzero(@(A_) 1 + hot_term(A_) + cold_term(A_) - A_, [1.00001, 10000]);
end

% Copyright 2012 Peter Desnoyers
% This file is free software: you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 2 of the License, or
% (at your option) any later version.
%
% It is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
% General Public License for more details. 
% You should have received a copy of the GNU General Public License
% along with this file. If not, see http://www.gnu.org/licenses/. 
